Device

Struct Device 

pub struct Device { /* private fields */ }
Represents a single device in the USB database.

Every device has a corresponding vendor, a device ID, a pretty name, and a list of associated Interfaces.

Implementations

Source

impl Device

pub fn from_vid_pid(vid: u16, pid: u16) -> Option<&'static Device>

Returns the Device corresponding to the given vendor and product IDs, or None if no such device exists in the DB.

use usb_ids::Device;
let device = Device::from_vid_pid(0x1d6b, 0x0003).unwrap();
assert_eq!(device.name(), "3.0 root hub");
pub fn vendor(&self) -> &'static Vendor

Returns the Vendor that this device belongs to.

Looking up a vendor by device is cheap (O(1)).

pub fn as_vid_pid(&self) -> (u16, u16)

Returns a tuple of (vendor id, device/“product” id) for this device.

This is convenient for interactions with other USB libraries.

pub fn id(&self) -> u16

Returns the device’s ID.

pub fn name(&self) -> &'static str

Returns the device’s name.

pub fn interfaces(&self) -> impl Iterator<Item = &'static Interface>

Returns an iterator over the device’s Interfaces.

NOTE: The USB database does not include interface information for most devices. This list is not authoritative.