SubClass

Struct SubClass 

pub struct SubClass { /* private fields */ }
Represents a class subclass in the USB database. Subclasses are part of the USB class code triplet (base class, subclass, protocol).

Contained within a Class and may contain a list of associated Protocols.

Implementations

Source

impl SubClass

pub fn from_cid_scid(class_id: u8, id: u8) -> Option<&'static Self>

Returns the SubClass corresponding to the given class and subclass IDs, or None if no such subclass exists in the DB.

use usb_ids::SubClass;
let subclass = SubClass::from_cid_scid(0x02, 0x03).unwrap();
assert_eq!(subclass.name(), "Telephone");

assert!(SubClass::from_cid_scid(0x3c, 0x02).is_none());
pub fn class(&self) -> &'static Class

Returns the Class that this subclass belongs to.

Looking up a class by subclass is cheap (O(1)).

use usb_ids::SubClass;
let subclass = SubClass::from_cid_scid(0x02, 0x03).unwrap();
let class = subclass.class();
assert_eq!(class.id(), 0x02);
pub fn as_cid_scid(&self) -> (u8, u8)

Returns a tuple of (class id, subclass id) for this subclass.

This is convenient for interactions with other USB libraries.

pub fn id(&self) -> u8

Returns the subclass’ ID.

pub fn name(&self) -> &'static str

Returns the subclass’ name.

pub fn protocols(&self) -> impl Iterator<Item = &'static Protocol>

Returns an iterator over the subclasses’s Protocols.

NOTE: The USB database nor USB-IF includes protocol information for all subclassess. This list is not authoritative.